@@ -11,7 +11,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  *
  * Copyright 2005 Todd Kulesza
  *
@@ -24,7 +25,6 @@
 #include <string.h>
 #include <libxml/parser.h>
 #include <glib.h>
-#include <curl/curl.h>
 
 #include "atom.h"
 
@@ -88,7 +88,10 @@ atom_build_packet (AtomEntry *entry)
 	child = xmlNewTextChild (node, NULL, (xmlChar *)"content", (xmlChar *)entry->content);
 	xmlNewProp (child, (xmlChar *)"type", (xmlChar *)"text/html");
 	xmlNewProp (child, (xmlChar *)"mode", (xmlChar *)"escaped");
-	
+	child = xmlNewChild (node, NULL, (xmlChar *)"author", NULL);
+	xmlNewTextChild (child, NULL, (xmlChar *)"name", BAD_CAST " ");
+	xmlNewTextChild (child, NULL, (xmlChar *)"email", BAD_CAST " ");
+
 	/* output the XML */
 	xmlDocDumpFormatMemoryEnc (doc, &xml, &bufsize, "UTF-8", 0);
 	
