@@ -11,12 +11,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  *
  * Copyright 2005 Todd Kulesza
+ * Copyright 2009 Neil Williams  <linux@codehelp.co.uk>
  *
  * Authors:
  * 		Todd Kulesza <todd@dropline.net>
+ * 		Neil Williams  <linux@codehelp.co.uk>
  */
 
 #ifndef _BLOG_ADVOGATO_H_
@@ -25,24 +28,15 @@
 #include "drivel_request.h"
 #include "drivel.h"
 
-DrivelRequest*
+void
 blog_advogato_build_login_request (const gchar *username, const gchar *password,
-		const gchar *uri);
+				   const gchar *uri);
 
 void
-blog_advogato_parse_login_request (DrivelClient *dc, DrivelRequest *dr);
-
-DrivelRequest*
 blog_advogato_build_postevent_request (const gchar *cookie, const gchar *uri, 
 		gint index, const gchar *title, const gchar *content);
 
 void
-blog_advogato_parse_postevent_request (DrivelClient *dc, DrivelRequest *dr);
-
-DrivelRequest*
 blog_advogato_build_getevents_request (const gchar *username, const gchar *uri);
 
-void
-blog_advogato_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr);
-
 #endif /* _BLOG_ADVOGATO_H_ */
