@@ -251,7 +251,7 @@ parse_login_request (SoupMessage *msg, gpointer data)
 			GTK_WINDOW (dc->current_window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_INFO,
-			GTK_BUTTONS_OK,
+			GTK_BUTTONS_OK, "%s",
 			message);
 		
 		gtk_dialog_run (GTK_DIALOG (dialog));
