@@ -11,7 +11,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  *
  * Copyright 2004 Todd Kulesza
  *
@@ -25,6 +26,7 @@
 
 #include <config.h>
 #include <glib.h>
+#include <libsoup/soup.h>
 
 typedef enum
 {
@@ -53,8 +55,8 @@ typedef enum
 	REQUEST_PROTOCOL_NONE,
 	REQUEST_PROTOCOL_POST,
 	REQUEST_PROTOCOL_GET,
-	REQUEST_PROTOCOL_XMLRPC,
-	REQUEST_PROTOCOL_ATOM
+	REQUEST_PROTOCOL_PUT,
+	REQUEST_PROTOCOL_DELETE,
 } DrivelRequestProtocol;
 
 typedef enum
@@ -95,6 +97,7 @@ struct _DrivelRequest
 	GSList *current;
 	GHashTable *request_values;
 	gchar *uri;
+	SoupMessage *msg;
 };
 
 /* Create an empty DrivelRequest */
@@ -106,6 +109,11 @@ DrivelRequest*
 drivel_request_new_with_items (DrivelRequestType type, 
 		DrivelRequestProtocol protocol, DrivelBlogAPI api, const gchar *uri, ...);
 
+/* Create a DrivelRequest with a type and SoupMessage */
+DrivelRequest*
+drivel_request_new_with_msg (DrivelRequestType type, 
+		DrivelRequestProtocol protocol, DrivelBlogAPI api, const gchar *uri, SoupMessage *msg);
+
 /* Add multiple items to a DrivelRequest.  Terminate the list with NULL. */
 void
 drivel_request_add_items (DrivelRequest *dr, ...);
@@ -114,6 +122,12 @@ drivel_request_add_items (DrivelRequest *dr, ...);
 void
 drivel_request_remove_items (DrivelRequest *dr, ...);
 
+void
+drivel_request_set_msg (DrivelRequest *dr, SoupMessage *msg);
+
+SoupMessage*
+drivel_request_get_msg (DrivelRequest *dr);
+
 /* Set the DrivelRequestType */
 void
 drivel_request_set_type (DrivelRequest *dr, DrivelRequestType type);
