@@ -281,7 +281,7 @@ gtk_dateentry_popup_display (GtkDateEntry * dateentry)
 	gint month;
 
 	/*gint height, width, x, y;*/
-	gint old_width, old_height;
+	gint G_GNUC_UNUSED old_width, G_GNUC_UNUSED old_height;
 
 	debug (" (dateentry) popup_display");
 
@@ -606,9 +606,9 @@ gtk_dateentry_init (GtkDateEntry * dateentry)
 static void
 gtk_dateentry_class_init (GtkDateEntryClass * klass)
 {
-	GObjectClass *gobject_class;
+	GObjectClass * G_GNUC_UNUSED gobject_class;
 	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
+	GtkWidgetClass * G_GNUC_UNUSED widget_class;
 
 	gobject_class = (GObjectClass*) klass;
 	object_class = (GtkObjectClass*) klass;
