@@ -544,7 +544,7 @@ login_changed_cb (GtkWidget *entry, gpointer data)
 static G_GNUC_UNUSED void
 password_changed_cb (GtkWidget *entry, gpointer data)
 {
-	gboolean state, username;
+	gboolean state, G_GNUC_UNUSED username;
 	DrivelClient *dc = (DrivelClient *) data;
 	
 	state = get_sensitivity (entry);
