@@ -11,7 +11,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  *
  * Copyright 2002 Todd Kulesza
  *
@@ -22,7 +23,7 @@
 #ifndef _LOGIN_H_
 #define _LOGIN_H_
 
-#include <gnome.h>
+/*#include <gnome.h>*/
 
 #include "drivel.h"
 
@@ -41,4 +42,7 @@ get_drivel_user (DrivelClient *dc);
 void
 user_list_changed (DrivelClient *dc);
 
+void
+refresh_recent_chooser (DrivelClient *dc);
+
 #endif
