@@ -72,7 +72,7 @@ display_error_dialog (DrivelClient *dc, const gchar *header, const gchar *mesg)
 				GTK_WINDOW (dc->current_window),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_CLOSE,
+				GTK_BUTTONS_CLOSE, "%s", 
 				error_string);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -556,7 +556,7 @@ drivel_gconf_data_fill (DrivelGConfData *data, const gchar *username,
 	gconf_client_add_dir (client, base, GCONF_CLIENT_PRELOAD_NONE, NULL);
 
 	add_gconf_notifies (dc);
-	
+	g_free (uid);
 	return;
 }
 
